@@ -334,7 +334,7 @@ void StarArray::Search(const std::string &search, StringList filelist,
 //  This does not, however, call StarArray::Display(); that's up to the
 //  main program.
 
-bool StarArray::SetRules(const Rules &rules, changetype_t ruleschange)
+bool StarArray::SetRules(const Rules &rules, star_changetype_t ruleschange)
 {
   ArrayRules = rules;
 
