@@ -199,8 +199,17 @@ bool dm(const string &record, name namespec, StringList *starnames)
   // which catalog: CP, SD, BD or CP
   catalog = dname.substr(0, 2);
   starstrings::toupper(catalog);
-  if (catalog != "CP" && catalog != "BD" && catalog != "CD" && catalog != "SD")
-    return false;
+  if (catalog != "BD" && catalog != "CD" && catalog != "CP" && catalog != "SD")
+  {
+    // hack to work around weird format of these entries in Hipparcos catalog
+    if ((catalog[0] == 'B' || catalog[0] == 'C' || catalog[0] == 'S')
+	&& !std::isalpha(catalog[1]))
+      catalog[1] = 'D';
+    else if (catalog[0] == 'P' && !std::isalpha(catalog[1]))
+      catalog = "CP";
+    else
+      return false;
+  }
 
   // value of degree sign (+ or -)
   if (dname.find('-') < dname.size())
