@@ -301,10 +301,11 @@ bool read_params(const string &filename)
     else if (assign[0] == string("CelestialCoords"))
       set_coord_item(static_cast<bool>(starmath::atoi(assign[1])), false);
     else if (assign[0] == string("StarDiameters"))
-      set_diameter_item(static_cast<diameter_t>(starmath::atoi(assign[1])),
+      set_diameter_item(static_cast<star_diameter_t>(starmath::atoi(assign[1])),
 		        false);
     else if (assign[0] == string("StarLabels"))
-      set_label_item(static_cast<label_t>(starmath::atoi(assign[1])), false);
+      set_label_item(static_cast<star_label_t>(starmath::atoi(assign[1])),
+			false);
     else if (assign[0] == string("StarBars"))
       set_toggle_item(&globals::chart_rules.StarBars,
 		      static_cast<bool>(starmath::atoi(assign[1])),
