@@ -148,7 +148,7 @@ print_double_to_text(GtkTreeViewColumn *column,
   /* Free the previous (default) text of the column's renderer. */
   g_free (cell_text->text);
   /* Get the double value from the model. */
-  gtk_tree_model_get (treemodel, iter, (int)data, &d, -1);
+  gtk_tree_model_get (treemodel, iter, (long)data, &d, -1);
   /* Now we can format the value ourselves. */
   cell_text->text = g_strdup (starstrings::ftoa(d, 4).c_str());
 }
