@@ -226,7 +226,8 @@ void my_gtk_popup_button(GtkWidget **close, GtkWidget *box, GtkWidget *window)
  *  is the type of display update to perform. */
 
 template<class T> void
-set_item(T *itemptr, T value, GtkWidget *menuptr, bool redraw, changetype_t c)
+set_item(T *itemptr, T value, GtkWidget *menuptr, bool redraw,
+	 star_changetype_t c)
 {
   // this keeps track of whether or not a particular item should be changed
   static std::map<T *, bool> enabled;
@@ -278,7 +279,7 @@ void toggle_grid()
 void toggle_legend() 
 { flip_toggle_item(&globals::chart_rules.ChartLegend, TOGGLE_LEGEND, true); }
 
-void set_label_item(label_t l, bool redraw)
+void set_label_item(star_label_t l, bool redraw)
 {
   if (globals::chart_rules.StarLabels == l) return;
 
@@ -295,7 +296,7 @@ void labels_landmk()    { set_label_item(LANDMARK_LABEL, true); }
 void labels_numerical() { set_label_item(NUMBER_LABEL, true); }
 void labels_off()       { set_label_item(NO_LABEL, true); }
 
-void set_diameter_item(diameter_t d, bool redraw)
+void set_diameter_item(star_diameter_t d, bool redraw)
 {
   if (globals::chart_rules.StarDiameters == d) return;
 
